// -*-java-*-
// $Id: restobook.js,v 1.6 2007/08/21 07:45:55 asc Exp $

// http://www.aaronland.info/javascript/restobook/
// http://www.aaronland.info/weblog/2007/07/28/trees/#delmaps

// Copyright (c) 2007 Aaron Straup Cope. All Rights Reserved.
// This is free software, you may use it and distribute it under the
// same terms as Perl itself.

function Restobook () {
    this._properties = {};
    this._stz = new sanitize();
}

Restobook.prototype.parse = function (str) {

    this._properties = {};

    var re  = new RegExp(/\s?\:([^\s]+)\s?"([^"]+)";/);
    str = str.replace(/&quot\;/g, "\"");

    var matches = 0;

    while (m = re.exec(str)){
	matches += 1;
	this._properties[m[1]] = m[2];
	str = str.replace(m[0], "");
    }

    return matches;
};

Restobook.prototype.phone = function (phone) {
    return this.getstore('phone', phone);
}

Restobook.prototype.address = function (address) {
    return this.getstore('address', address);
}

Restobook.prototype.yelp = function (id) {
    return this.getstore('yelp', id);
}

Restobook.prototype.set = function (label, value){
    this._properties[label] = value;
};

Restobook.prototype.get = function (label, raw){

	if (raw){
		return this._properties[label]
	}

	return this.stringify_one(label);
};

Restobook.prototype.getstore = function (label, value){

    if (value) {
        this.set(label, value);
    }

    return this.get(label);
}

Restobook.prototype.stringify = function () {
    var parts = new Array();

    for (label in this._properties){

        if (this._properties[label]){
            parts.push(this.stringify_one(label));
        }
    }

    return parts.join(" ");
};

Restobook.prototype.stringify_one = function (label) {
    return ":" + label + " \"" + this._properties[label] + "\";";
}

Restobook.prototype.asHTML = function () {
    // there must be a better way...
    var dom = this.asDOM();
    var div = document.createElement("div");
    div.appendChild(dom);
    return div.innerHTML;
};

Restobook.prototype.asDOM = function () {

    var fixed = new Array('address', 'phone', 'hours');
    var other = new Array();

    var re = new RegExp("(?:" + fixed.join("|") + ")");

    for (var label in this._properties) {

        if (re.exec(label)){
                continue;
        }

        other.push(label);
    }

    other.sort();
    fixed = fixed.concat(other);

    var ul = document.createElement("ul");
    ul.setAttribute("class", "restobook");

    for (var i in fixed){
	var label = fixed[i];

	if (! this._properties[label]){
		continue;
        }

	var li = document.createElement("li");
        li.setAttribute("class", "restobook_" + label);

        if (label=='yelp'){
              var a = document.createElement("a");
              a.setAttribute("href", this.yelp_url(this._properties[label]));
              a.setAttribute("target", "_yelp"); 
              a.appendChild(document.createTextNode("yelp"));
              li.appendChild(a);
        }

        else {
	      li.appendChild(document.createTextNode(this._stz.sanitize_string(this._properties[label])));
        }

        ul.appendChild(li);
    }	

    return ul;
};

Restobook.prototype.yelp_url = function(yelp_id, sub){

	if (! sub){
		sub = "www";
	}

	return "http://" + sub + ".yelp.com/biz/" + this._stz.sanitize_url_string(yelp_id);
};
